<div align="center">
  <img height="90" src="logos/mold_horizontal_logo_dark_300dpi.png" alt="Logo" align="center">
</div>

# MOLDE
**M**OPT **L**ightweight **De**esign (MOLDE) is a library created to standardize and make easier the creation and maintainance of internal products of the Multidisciplinary Optimization Group (MOPT).

Here are the colors, icons, fonts and common interface components, that may be usefull for multiple MOPT projects.

This is heavily inspired by [Carbon Design System](https://carbondesignsystem.com/), [Atlassian Design System](https://atlassian.design/), [Fast Design System](https://www.fast.design/), [Material Design](https://m3.material.io/) and [Bold Design System](https://bold.bridge.ufsc.br/pt/).

# Colors 
The color palettes are available [here](https://andrefpf.github.io/molde/).

# Icons 
A lot of free to use icons, from Material Design, are available [here](https://fonts.google.com/icons).
Other icons may be necessary, and they will be made to match the same style.
For consistency avoid using icons from other places.

# Typeface
The font choose for this system is [IBM Plex](https://www.ibm.com/plex/).
The `.ttf` files for every version of the font, including monospaced, can be found [here](https://github.com/IBM/plex/tree/master/packages).

# Component
The sylesheets of the Qt components are designed to make it similar to [Atlassian components](https://atlassian.design/components/).
Always check for the Atlassian component usage guide in case of any doubt.
